<?php
namespace Teknisa\SUP\Modules\Cotacao\Modules\Pedido\Controllers;

use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Teknisa\SUP\Util\SupUtilities;

class ControlePedidoColeta extends \Teknisa\GER\Controllers\TeknisaCrud
{

    protected $crudService;
    protected $controlePedidoColetaService;
    protected $controlePedidoColetaAceite;
    protected $dataSourceManager;
    protected $smtpUtil;
    protected $entityManager;
    protected $zhFileUploader;
    protected $fileServerURL;
    protected $supUtilities;

    public function __construct($crudService, $parameterBag, $controlePedidoColetaService, $controlePedidoColetaAceite, $dataSourceManager, $smtpUtil, EntityManager $entityManager, $zhFileUploader, $fileServerURL, SupUtilities $supUtilities) 
    { 
        $this->crudService = $crudService;
        $this->parameterBag = $parameterBag;
        $this->controlePedidoColetaService = $controlePedidoColetaService;
        $this->controlePedidoColetaAceite = $controlePedidoColetaAceite;
        $this->dataSourceManager = $dataSourceManager;
        $this->smtpUtil = $smtpUtil;
        $this->entityManager = $entityManager;
        $this->templatesDir = realpath(__DIR__ . '/../../../../../Util/Template');
        $this->zhFileUploader    = $zhFileUploader;
        $this->fileServerURL     = $fileServerURL;
        $this->supUtilities = $supUtilities;
    }

    public function filtroPedido(DTO\Request\Filter $request, DTO\Response $response)
    {
        $conditions = $request->getFilterCriteria()->getConditions();
        $pedidos = $this->crudService->getFilteredDataSet("sup03600_controle_pedcol", $conditions)->getRows();
        $parents = array();

        foreach ($pedidos as &$pedido) {
            if (!isset($parents[$pedido['NRPEDGRID']])) {
                $parents[$pedido['NRPEDGRID']] = array(
                    'ID'                => $pedido['NRPEDGRID'],
                    'INSCRICAO'         => $pedido['NRINSJURFORN'],
                    'FORNECEDOR'        => $pedido['NMFANTFORN'],
                    'SITUACAO'          => $pedido['IDSITUPEDCOLETA'],
                    'OPERACEITE'        => $pedido['OPERACEITE'],
                    'TOTAL_ATUAL'       => null,
                    'QUANTIDADE'        => null,
                    'TOTAL_ANTERIOR'    => null,
                    'DIFERENCA'         => null,
                    'DIFERENCAPERC'     => null,
                    'VRTOTALPRECREN'    => null,
                    'TOTALOBJ'          => null,
                    'NRPEDGRID'         => $pedido['NRPEDGRID'],
                    'NRPEDIDOCOL'       => $pedido['NRPEDIDOCOL'],
                    'NRPEDCOLETA'       => $pedido['NRPEDCOLETA'],
                    'CDFORNECED'        => $pedido['CDFORNECED'],
                    'CDREGIAO'          => 'T',
                    'COMPRADOR'         => $pedido['COMPRADOR'],
                    'CDFILIAL'          => $pedido['CDFILIAL'],
                    'REGIAO'            => $pedido['NMREGIAO'],
                    'CDOPERLANC'        => $pedido['CDOPERLANC'],
                    'IDRENEGOCIAPCOL'   => $pedido['IDRENEGOCIAPCOL'],
                    'IDSITUCOLETAGERAL' => $pedido['IDSITUCOLETAGERAL'],
                    'IDSITUPEDCOL'      => $pedido['IDSITUPEDCOL'],
                    'DTEXPIRAPEDCOL'    => $pedido['DTEXPIRAPEDCOL'],
                    'DTINIPERGERAL'     => $pedido['DTINIPERGERAL'],
                    'DTFINPERGERAL'     => $pedido['DTFINPERGERAL'],
                    'DTVALIDADE'        => $pedido['DTINIPERGERAL'] . ' - ' . $pedido['DTFINPERGERAL']
                );
            }
            
            $pedido['PARENT'] = $parents[$pedido['NRPEDGRID']]['ID'];
        };
        
        $newParent = $this->somaTotais($parents, $pedidos);
        
        foreach ($newParent as &$parent) {
            $cotacao  = $parent['TOTAL_ATUAL'];
            $anterior = $parent['TOTAL_ANTERIOR'];
            
            $parent['DIFERENCA'] = (($cotacao)-($anterior));
            
            if ($anterior >0) {
                $parent['DIFERENCAPERC'] = (($cotacao-$anterior)/$anterior)*100;
            } else {
                $parent['DIFERENCAPERC'] = 0;
            }
        }
        
        $datasetPais   = array_values($newParent);
        $datasetFilhos = array_values($pedidos);
        $dataset = array_merge($datasetPais, $datasetFilhos);
        $response->addDataSet(new DataSet("pedidos", $dataset));
    }
    
    public function somaTotais($parents, $pedidos) 
    {
        foreach ($parents as &$parent) {
            foreach ($pedidos as $pedido) {
                if($parent['ID'] == $pedido['PARENT']) {
                    $parent['TOTAL_ATUAL']    += $pedido['TOTAL_ATUAL'];
                    $parent['TOTAL_ANTERIOR'] += $pedido['TOTAL_ANTERIOR'];
                    $parent['VRTOTALPRECREN'] += $pedido['VRTOTALPRECREN'];
                    $parent['TOTALOBJ']       += $pedido['TOTALOBJ'];
                }
            }
        }
        
        return $parents;
    }
    
    public function buildTotals($pedidos) 
    {
        foreach ($pedidos as &$pedido) {
            $pedido['TOTALANT']     = $pedido['VRPRECUNITANT']    * $pedido['QUANTIDADE'];
			$pedido['TOTALATUAL']   = $pedido['VRPRECUNIT'] 	  * $pedido['QUANTIDADE'];
			$pedido['VLRTOTALOBJ']  = $pedido['VRPRECOOBJETIVO']  * $pedido['QUANTIDADE'];
			$pedido['VLRTOTALRET']  = $pedido['VRPRECREN']        * $pedido['QUANTIDADE'];
			
			if ($pedido['VRPRECUNITANT'] == 0) {
			    $pedido['VARCOTACAO']   = 0;
                $pedido['VARRENEGOCIA'] = 0;
                $pedido['VAROBJETIVO']  = 0;
			} else {
                $pedido['VARCOTACAO']   = (($pedido['VRPRECUNIT']	   - $pedido['VRPRECUNITANT']) / ($pedido['VRPRECUNITANT']))*100;
                $pedido['VARRENEGOCIA'] = (($pedido['VRPRECREN']	   - $pedido['VRPRECUNITANT']) / ($pedido['VRPRECUNITANT']))*100;
                $pedido['VAROBJETIVO']  = (($pedido['VRPRECOOBJETIVO'] - $pedido['VRPRECUNITANT']) / ($pedido['VRPRECUNITANT']))*100;
			}
        }
        
        return $pedidos;
    }
    
    public function swipeProduto(DTO\Request\Filter $request, DTO\Response $response)
    {
        $conditions = $request->getFilterCriteria()->getConditions();
        
        $itensPedido = $this->crudService->getFilteredDataSet("sup03600_produtos_pedcol", $conditions, $request->getFilterCriteria()->getPage(), $request->getFilterCriteria()->getPageSize())->getRows();
        $itemsWithTotals = $this->buildTotals($itensPedido);
        $response->addDataSet(new DataSet("produtoPedcol", $itemsWithTotals));
    }

    public function negociacao(DTO\Request\Filter $request, DTO\Response $response)
    {
        $this->dataSourceName = "sup03600_grafico_negociacao";
        $this->parameterBagColumns = array('CDFILIAL', 'NRPEDIDOCOL', 'DTINIVALPCOL', 'DTFINVALPCOL', 'CDPRODUTO', 'CDMARCA');
        
        $this->find($request, $response);
    }

    public function saveProduto(DTO\Request $request, DTO\Response $response)
    {
        $produtos = $request->getRow();
        
        try {
            $this->controlePedidoColetaService->iniciaTransacao();
            
            foreach ($produtos as $produto) {
                $produto['VRPRECOOBJETIVO'] = str_replace('.','',$produto['VRPRECOOBJETIVO']);
                $produto['VRPRECOOBJETIVO'] = str_replace(',','.',$produto['VRPRECOOBJETIVO']);
                $produto['IDITPEDPRIONEG'] = 'S';
                
                $this->controlePedidoColetaService->atualizaPrecObj($produto);
                $this->controlePedidoColetaService->atualizaPrecObjItmPedCol($produto);
                $this->controlePedidoColetaService->preencheGrafico($produto);
            }
            
            $this->controlePedidoColetaService->flush();
            $this->controlePedidoColetaService->commit();
            
            $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message('Save successful'));
        } catch(\Exception $e) {
            $this->controlePedidoColetaService->rollback();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 1));
        }
    }

    public function updateSituacao(DTO\Request $request, DTO\Response $response)
    {
        $pedidos = $request->getRow();
        
        try {
            $this->controlePedidoColetaService->iniciaTransacao();
            
            foreach ($pedidos['PEDIDOS'] as $pedido) {
                $this->controlePedidoColetaService->atualizaSituPedcolgeral($pedido, $pedidos['DTEXPIRAPEDCOL']);
                $this->controlePedidoColetaService->atualizaSituPedcoleta($pedido);
            }
            
            $this->controlePedidoColetaService->flush();
            $this->controlePedidoColetaService->commit();
        } catch(\Exception $e) {
            $this->controlePedidoColetaService->rollback();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 1));
        }        
    }
    
    
    public function verificaInconsistenciaGeraCot($pedidos, $response) 
    {

        $inconsistencia = array();
        $existInconsist = false;
        
        foreach ($pedidos as $pedido) {
            $pedido['IDCONSISTE'] = 'S';
            $code = $this->controlePedidoColetaService->ACEITA_PEDCOTWEB($pedido);
           
           //Verifica se o fornecedor está inativo fora da procedure, porque ela não estava verificando o mesmo.
            $verificaFornecedorInativo = $this->controlePedidoColetaService->verificaFornecedorInativo($pedido['CDFORNECED']);

            if($code['P_IDACEITEOK'] === 'ERRO' || $verificaFornecedorInativo[0]['IDSITUCADA'] === 'I'){
                $pedidoInconsistente = array(
                    'NRPEDIDOCOL' => $pedido['NRPEDIDOCOL'],
                    'FORNECEDOR' => $pedido['FORNECEDOR']
                );
                $inconsistencia[] = $pedidoInconsistente;
                $this->controlePedidoColetaService->alteraStatus($pedido['NRPEDIDOCOL'], $pedido['CDFILIAL'], $pedido['CDFORNECED'], $pedido['NRPEDCOLETA'], 'inconsistencia');
                $existInconsist = true;
            }
        }
        if($existInconsist){
            $this->controlePedidoColetaService->commit();
            return $inconsistencia;
        } 
        return false;
        
    }


    public function geraCotacaoWeb(DTO\Request $request, DTO\Response $response){
        $row = $request->getRow();
        $mensagem = 'N';
        $inconsistencia = false;
        $code = 1;
        $erroVerificaIncGeraCot = false;
        try{
            $this->controlePedidoColetaService->iniciaTransacao();
            if(!$row['FINALIZEINCONSIST']){
                $inconsistencia = $this->verificaInconsistenciaGeraCot($row['PEDIDOSPAI'], $response);
                if($inconsistencia){
                    $erroVerificaIncGeraCot = true;
                }
                if(!$row['FINALIZEPROCESSACEITE']){
                    $this->controlePedidoColetaAceite->verifyParamTermoAceite($row['FILIAL_LOGADA'], $row['PEDIDOS'], $row['NMOPERADORLOGADO'], $row['EMAILLOGADO'], $row['PEDIDOSPAI'], $response);
                }
            }

            foreach ($row['PEDIDOS'] as $pedido) {
                $nrpedcoleta = $pedido['NRPEDCOLETA'];
                $cdforneced  = $pedido['CDFORNECED'];
                $cdregiao    = $pedido['CDREGIAO'];
                $cdfilial    = $pedido['CDFILIAL'];
                $nrsemini    = $pedido['NRSEMINI']; 
                $nrsemifin   = $pedido['NRSEMFIN'];
                $entralista  = $row['LISTAPREC'];
                
                $idutstatuslispr = $this->controlePedidoColetaService->selectIdutstatuslispr($cdfilial)[0];
                if($idutstatuslispr['IDUTSTATUSLISPR'] === 'S' && $entralista === 'S'){
                    $adqColetaListas = $this->controlePedidoColetaService->adqColetaLista($cdfilial, $cdregiao,$cdforneced,$nrpedcoleta);
                    if(!empty($adqColetaListas)){
                        foreach($adqColetaListas as $adqColetaLista){
                            $cdcomprador = $adqColetaLista['CDOPERADOR'];
                            $dtInicial = $adqColetaLista['DTINIPERCOT'];
                            $dtFinal = $adqColetaLista['DTFINPERCOT'];
                             $adqExisteListas = $this->controlePedidoColetaService->adqExisteLista($cdcomprador,$dtInicial,$dtFinal);
                             if(!empty($adqExisteListas)){
                                 foreach($adqExisteListas as $adqExisteLista){
                                     $nrseqprelist = $adqExisteLista['NRSEQPRELIST'];
                                     $cdfilial    = $adqExisteLista['CDFILIAL'];
                                     $adqExisteCotacao = $this->controlePedidoColetaService->adqExisteCotacao($cdfilial, $cdcomprador,$nrseqprelist,$dtFinal,$dtInicial)[0];
                                     if($adqExisteCotacao['CONTADOR'] == 0){
                                         $adqExisteCotacao1 = $this->controlePedidoColetaService->adqExisteCotacao1($cdfilial, $cdcomprador,$dtFinal,$dtInicial)[0];
                                         if($adqExisteCotacao1['CONTADOR'] > 0){
                                             $mensagem = 'Não foi gerada cotação para um ou mais pedidos de coleta pois estes possuem uma data de validade para a qual já existe uma lista de preços cujo status é ou já foi "Definitiva".';
                                         }
                                     }else{
                                         $mensagem = 'Não foi gerada cotação para um ou mais pedidos de coleta pois estes possuem uma data de validade para a qual já existe uma lista de preços cujo status é ou já foi "Definitiva".';
                                     }
                                 }
                             }
                        }
                    }
                }
                
                
                $cdfilial    = $pedido['CDFILIAL'];
                $retorno = $this->controlePedidoColetaService->geraCotacao($nrpedcoleta, $cdforneced, $cdregiao, $cdfilial, $nrsemini, $nrsemifin, $entralista);
                if($retorno['P_COTA_N_GER'] == 'S'){
                    $erroVerificaIncGeraCot = true;
                }
            }
            
            
            if($row['FINALIZEPROCESSACEITE']){
                $this->controlePedidoColetaAceite->enviaEmailComprador($row);
            }
            
            if($erroVerificaIncGeraCot){
                throw new \Exception('', 13);
            }
            
            $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message($mensagem));
        } catch(\Exception $e){
            $responseMsg = array();
            //Se o throw new Exception estiver passando o código 13 como parâmetro não é necessário dar rollback devido a modificação de status no banco.
            if($e->getCode() === 13 || $erroVerificaIncGeraCot){
                $code = 13;
                $responseMsg['CODE'] = $e->getMessage();
                $responseMsg['PARAM'] = $inconsistencia ? $inconsistencia : '';
            }else {
                $this->controlePedidoColetaService->rollback();
                $responseMsg['CODE'] = "ERR_GENERICO";
                $responseMsg['PARAM'] = $e->getMessage();
            }
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($responseMsg, $code));
            
            
        }
    }
    
    public function enviaEmailFornecedor(DTO\Request $request, DTO\Response $response)
    {
        $email = $request->getRow();
        
        try {
            
            if (array_key_exists('PEDIDOS', $email)) {
                
                foreach ($email['PEDIDOS'] as $pedido) {
                    $mensagem = $email['MENSAGEM'] . "<br/><strong>Pedido de Coleta: </strong>" . $pedido['NRPEDIDOCOL'];
                
                    $messageSendMail = $this->supUtilities->messageSendMail($email['FILIAL_LOGADA'], $email['ASSUNTO'], $mensagem, 'PORTAL E-COMMERCE');
                    
                    $emailFornecedor = $this->supUtilities->retornarEmailsRelacionadosFornecedor([$pedido['CDFORNECED']]);
                    $this->supUtilities->enviaEmail(false, $email['ASSUNTO'], false, $messageSendMail, $emailFornecedor);
                }
                
            } else {
                
                $messageSendMail = $this->supUtilities->messageSendMail($email['FILIAL_LOGADA'], $email['ASSUNTO'], $email['MENSAGEM'], 'PORTAL E-COMMERCE');
                $emailFornecedor = $this->supUtilities->retornarEmailsRelacionadosFornecedor($email['FORNECEDORES']);
                
                $this->supUtilities->enviaEmail(false, $email['ASSUNTO'], false, $messageSendMail, $emailFornecedor);
                
            }
            
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 1));
        }
    }
    
    public function defineCookieEmail(DTO\Request $request, DTO\Response $response)
    {
        $row = $request->getRow();
        
        $this->supUtilities->defineCookieEmail($row['NOME'], $row['MENSAGEM'], time() + (86400 * 999));
        
        $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message('Cookie successful'));
    }
    
    public function retornaCookieEmail(DTO\Request $request, DTO\Response $response)
    {
        $row = $request->getRow();
        
        $mensagem = $this->supUtilities->retornaCookieEmail($row['NOME']);
        
        $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message($mensagem));
    }
    
    public function retornaMenorMaiorProdutoPedido(DTO\Request $request, DTO\Response $response)
    {
        $pedidos = $request->getRow();
        $menorMaiorProduto = [];
        
        try {
            $produtos = $this->controlePedidoColetaService->retornaMenorMaiorProdutoPedido($pedidos);
            $qtdeProdutos = count($produtos);
            
            if ($qtdeProdutos) {
        	    $menorMaiorProduto = array(
        	        "PRODMIN" => $produtos[0]['CDARVPROD'],
        	        "NMPRODMIN" => $produtos[0]['NMPRODUTO'],
        	        "PRODMAX" => $produtos[$qtdeProdutos - 1]['CDARVPROD'],
        	        "NMPRODMAX" => $produtos[$qtdeProdutos - 1]['NMPRODUTO']
        	    );      
            }
            
            $response->addDataSet(new DataSet("retornaMenorMaiorProdutoPedido", $menorMaiorProduto));
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 1));
        }
    }
    
    public function calculaPrecoObjetivo(DTO\Request $request, DTO\Response $response)
    {
        $pedidos = $request->getRow();
        
        $listaPedidos = $pedidos['LISTAPEDIDOS'];
        $consideraMarca = $pedidos['CONSIDERAMARCA'];
        $paramCompPreco = $pedidos['PARAMCOMPPRECO'];

        try {
            $this->controlePedidoColetaService->iniciaTransacao();
            
            $nrlista = $this->controlePedidoColetaService->insereLista($listaPedidos);
            $listaProdutosValorMinimo = $this->controlePedidoColetaService->retornaProdutosValorMinimo($consideraMarca, $nrlista, $paramCompPreco);
            
            if (((is_array($listaProdutosValorMinimo) && !is_null($listaProdutosValorMinimo)) ? count($listaProdutosValorMinimo) : 0) > 0) {
                
                foreach ($listaProdutosValorMinimo as $produtoValorMinimo) {
                    $produtoValorMinimo['DSOBSRENEGOCIA'] = "Gentileza Verificar o Preço Objetivo!";
                    $this->controlePedidoColetaService->atualizaPrecObjMinPrmarcpedcol($produtoValorMinimo, implode('_',$listaPedidos), $paramCompPreco);
                    
                    $this->controlePedidoColetaService->retornaPedido($produtoValorMinimo, $nrlista, $paramCompPreco);
                    
                    foreach ($listaPedidos as $pedido) {
                        $this->controlePedidoColetaService->atualizaPrecObjMinItempedcol($produtoValorMinimo, $pedido, $paramCompPreco);
                    }
                }
                
                $retorno = array( 'NRLISTA' => $nrlista );
                
                $response->addDataSet(new DataSet('data', $retorno));
                
            } else {
                $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message('Não há dados para calcular preço objetivo!'));
            }
            
            $this->controlePedidoColetaService->commit();
        } catch(\Exception $e) {
            $this->controlePedidoColetaService->deletaLista($nrlista);
            $this->controlePedidoColetaService->rollback();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 1));   
        }
        
    }
    
    public function salvaPrecoObjetivoMinimo(DTO\Request $request, DTO\Response $response)
    {
        $pedidos = $request->getRow();
        $listaPedidos = $pedidos['LISTAPEDIDOS'];
        $produtos = $pedidos['PRODUTOS'];
        $precoObjetivoNull = 'S';
        $paramCompPreco = $pedidos['PARAMCOMPPRECO'];
        try {
            foreach ($produtos as $produto) {
                if(gettype($produto['VRPRECOOBJETIVO']) === 'string') {
                    $produto['VRPRECUNIPRMARC'] = str_replace('.','',$produto['VRPRECOOBJETIVO']);
                    $produto['VRPRECUNIPRMARC'] = str_replace(',','.',$produto['VRPRECUNIPRMARC']);
                    
                } else {
                    $produto['VRPRECUNIPRMARC'] = $produto['VRPRECOOBJETIVO'];
                }
               
                $this->controlePedidoColetaService->atualizaPrecObjMinPrmarcpedcol($produto, implode('_',$listaPedidos), $paramCompPreco, $precoObjetivoNull);
                foreach ($listaPedidos as $pedido) {
                    $this->controlePedidoColetaService->atualizaPrecObjMinItempedcol($produto, $pedido, $paramCompPreco);
                }
            }
        } catch(\Exception $e) {
            $this->controlePedidoColetaService->rollback();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 1));   
        }
        
    }
    
    public function deletaLista(DTO\Request $request, DTO\Response $response)
    {
        $nrlista = $request->getRow();
        
        try {
            $this->controlePedidoColetaService->deletaLista($nrlista['NRLISTA']);
        } catch(\Exception $e) {
            $this->controlePedidoColetaService->rollback();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 1));   
        }
    }
    
    public function salvarComentario(DTO\Request $request, DTO\Response $response)
    {
        $row = $request->getRow();
        try {
            $this->controlePedidoColetaService->iniciaTransacao();
            $row['DOCUMENTOANEXOFULLPATH'] = isset($row["fileUpload"]) && sizeof($row["fileUpload"]) ? $this->fileServerURL.$row["fileUpload"][0]["path"] : ' ';
            $this->controlePedidoColetaService->salvarComentario($row);
            $infoComentario  = $this->controlePedidoColetaService->infoComentario($row);
            $infoOperador    = $this->controlePedidoColetaService->infoOperador($row);
            $this->enviaEmailComentario($infoComentario, $row, $response, 'comentario');
            $this->controlePedidoColetaService->flush();
            $this->controlePedidoColetaService->commit();
        } catch (\Exception $e) {
            if($e->getCode() != 13){
                $this->controlePedidoColetaService->rollback();
            }
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 1));
        }
    }
    
     public function setFileFullPath(DTO\Request $request, DTO\Response $response) {
		$row = $request->getRow();
		
			if ($row["DSIDDOCFILESERV"] !== null) {
				$row["DOCUMENTOANEXOFULLPATH"] = $this->fileServerURL.$row["DSIDDOCFILESERV"];
			}
			$dataset = array(
                "row"   => $row
            );
            $response->addDataSet(new DataSet('data', $dataset));
	
	}
	

    public function enviaEmailComentario($infoComentario, $row, $response, $rotina){
        try{
            $assunto = 'Comentário - '.$infoComentario["NRPEDIDOCOL"];
            if($rotina === 'liberarInconsistencia'){
                $message = $this->controlePedidoColetaService->getMessageInconsistencia($infoComentario);
            }else{
                $message = $this->controlePedidoColetaService->getMessage($infoComentario);
            }
            $messageSendMail = $this->supUtilities->messageSendMail($row["FILIAL_LOGADA"], $assunto, $message, 'PORTAL E-COMMERCE');
            $emailFornecedor = $this->supUtilities->retornarEmailsRelacionadosFornecedor([$row['CDFORNECED']]);
            
            if(isset($row["fileUpload"]) && sizeof($row["fileUpload"])){
                $this->supUtilities->enviaEmail($row["EMAIL_LOGADO"], 'Comentário - '.$infoComentario["NRPEDIDOCOL"], $emailFornecedor, $messageSendMail, $emailFornecedor, $row["DOCUMENTOANEXOFULLPATH"], $row["fileUpload"][0]["name"], $row["fileUpload"][0]["type"]);
            }else{
                $this->supUtilities->enviaEmail($row["EMAIL_LOGADO"], 'Comentário - '.$infoComentario["NRPEDIDOCOL"], $emailFornecedor, $messageSendMail, $emailFornecedor);
            }
        }catch(\Exception $e){
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(),500));
        }
    }

    
    public function downloadFile(DTO\Request $request, DTO\Response $response) {
        $row = $request->getDataSet()->getRows()[0];
        $file = $row["DOCUMENTOANEXOFULLPATH"];
        $name = $row["DSDOCUMENTOANEXO"];
        $nameArray = explode(".", $name);
        $type = end($nameArray);
        header('Accept-Ranges: none');
        header("Content-Type: " . $type);
        header("Content-Disposition: attachment; filename=" . $name);
        readfile($file);
        exit;
    }
    
    public function deletaPedido(DTO\Request $request, DTO\Response $response)
    {
        $pedidos = $request->getRow();
        $pedidosExcluidos = [];
        try {
        
            $this->controlePedidoColetaService->iniciaTransacao();
            
            foreach ($pedidos as $pedido) {
                if ($pedido['IDSITUPEDCOLETA'] == "NR" || $pedido['IDSITUPEDCOLETA'] == "NN") {
                    
                    $this->controlePedidoColetaService->deletaLogacespedcol($pedido['CDFILIAL'], $pedido['NRPEDIDOCOL']);
                    $this->controlePedidoColetaService->deletaComentpedcol($pedido['CDFILIAL'], $pedido['NRPEDIDOCOL']);
                    $this->controlePedidoColetaService->deletaPedcoleta($pedido['CDFILIAL'], $pedido['NRPEDCOLETA'], $pedido['CDFORNECED'], $pedido['CDREGIAO']);
                    $this->controlePedidoColetaService->deletaItempedcol($pedido['CDFILIAL'], $pedido['NRPEDCOLETA'], $pedido['CDFORNECED'], $pedido['CDREGIAO']);
                    $this->controlePedidoColetaService->deletaRegiaopedcol($pedido['CDFILIAL'], $pedido['NRPEDIDOCOL'], $pedido['CDREGIAO']);
                    $this->controlePedidoColetaService->deletaPrmarcpedcol($pedido['CDFILIAL'], $pedido['NRPEDIDOCOL'], $pedido['CDFORNECED']);
                    $this->controlePedidoColetaService->deletaFornepedcol($pedido['CDFILIAL'], $pedido['NRPEDIDOCOL'], $pedido['CDFORNECED']);
                    
                    array_push($pedidosExcluidos, ["NRINSJURFORN" => $pedido['NRINSJURFORN'],"NMFANTFORN" => $pedido['NMFANTFORN'],"NRPEDIDOCOL" => $pedido['NRPEDIDOCOL'], "NRPEDCOLETA" => $pedido['NRPEDCOLETA'], "CDREGIAO" => $pedido['CDREGIAO'], "NMREGIAO" => $pedido['NMREGIAO'], "CDFORNECED" => $pedido['CDFORNECED'], "CDFILIAL" => $pedido['CDFILIAL']]);
                }
            }
            
            foreach ($pedidosExcluidos as $pedido) {
                $this->controlePedidoColetaService->deletaPedcolgeral($pedido['CDFILIAL'], $pedido['NRPEDIDOCOL']);
            }
            
            $this->controlePedidoColetaService->flush();
            $this->controlePedidoColetaService->commit();
            
            $response->addDataSet(new DataSet('pedidosExcluidos', $pedidosExcluidos));

        } catch(Exception $e) {
            $this->controlePedidoColetaService->rollback();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 1));
        }
    }
    
    public function verificaPedidoColetaGerado(DTO\Request $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();
            $pedidos = $row["PEDIDOS"];
            $filiais = [];
            $numPedidos = [];
            $regioes = [];
            $fornecedores = [];
            
            foreach ($pedidos as $pedido) {
                if (!in_array($pedido["CDFILIAL"], $filiais, true)) {
                    $filiais[] = $pedido["CDFILIAL"];
                }
                
                if (!in_array($pedido["NRPEDIDOCOL"], $filiais, true)) {
                    $numPedidos[] = $pedido["NRPEDIDOCOL"];
                }
                
                if (!in_array($pedido["CDREGIAO"], $filiais, true)) {
                    $regioes[] = $pedido["CDREGIAO"];
                }
                
                if (!in_array($pedido["CDFORNECED"], $filiais, true)) {
                    $fornecedores[] = $pedido["CDFORNECED"];
                }
            }
            
            $filiais = array_unique($filiais);
            $numPedidos = array_unique($numPedidos);
            $regioes = array_unique($regioes);
            $fornecedores = array_unique($fornecedores);
            
            $params = array(
                "P_CDFILIAL"    => join("_", $filiais),
                "P_NRPEDIDOCOL" => join("_", $numPedidos),
                "P_CDREGIAO"    => join("_", $regioes),
                "P_CDFORNECED"  => join("_", $fornecedores)
            );
            if (count($this->controlePedidoColetaService->pedidoColetaExists($params)) > 0) {
                throw new \Exception("Não é possível realizar esta ação, pois existem pedidos que possuem cotação gerada.");
            }
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 1));
        }
    }
    
    public function getQuantidadeComprar(DTO\Request $request, DTO\Response $response)
    {
        $produtos = '_';
        $regioes = '_';
        $fornecedores = '_';
        $pedidos = '_';
        
        try {
            $rows = $request->getDataSet()->getRows();
            foreach ($rows as $row) {
                if ($row["_parent"]) {
                    $regioes = $regioes.$row["CDREGIAO"].'_';
                    $fornecedores = $fornecedores.$row["CDFORNECED"].'_';
                    $pedidos = $pedidos.$row["NRPEDCOLETA"].'_';
                }
            }
            
            foreach ($rows as $row) {
                if ($row["_parent"]) {
                    $itensPedido = $this->crudService->getFilteredDataSet("sup03600_produtos_pedcol", $this->controlePedidoColetaService->filtroProdutosPedCol($row, $regioes))->getRows(); 
                    
                    foreach($itensPedido as $item){
                        if(strpos($produtos, $item['CDPRODUTO']) == 0) {
                            $produtos = $produtos.$item['CDPRODUTO'].'_'; 
                        }
                    }
                }
            }
            
            $prodAComp = $this->crudService->getFilteredDataSet("getQtdAComp", $this->controlePedidoColetaService->filtroQtdeComprar($row, $regioes, $produtos))->getRows(); 
            
            foreach ($prodAComp as $row) {
                $this->controlePedidoColetaService->atualizaQtdeAComprar($row, $regioes, $fornecedores, $pedidos);
            }
        
            $response->addMessage(new DTO\Response\Message($prodAComp));
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 1));
        }
    }
    
        public function getQuantidadeComprarMediaAF(DTO\Request $request, DTO\Response $response)
    {
        $produtos = '_';
        $regioes = '_';
        $fornecedores = '_';
        $pedidos = '_';
        
        try {
            $rows = $request->getRow();
            
            foreach ($rows["PEDIDOS"] as $row) {
                if ($row["_parent"]) {
                    $regioes = $regioes.$row["CDREGIAO"].'_';
                    $fornecedores = $fornecedores.$row["CDFORNECED"].'_';
                    $pedidos = $pedidos.$row["NRPEDCOLETA"].'_';
                }
            }
            
            foreach ($rows["PEDIDOS"] as $row) {
                if ($row["_parent"]) {
                    $itensPedido = $this->crudService->getFilteredDataSet("sup03600_produtos_pedcol", $this->controlePedidoColetaService->filtroProdutosPedCol($row, $regioes))->getRows(); 
                    foreach($itensPedido as $item){
                        if($rows["IDCONSFORNAF"] === "S")
                        { 
                           $row['QTACOMPRAR'] = $this->controlePedidoColetaService->selectQtdeAComprarMediaAF($row, $row["CDREGIAO"], $item['CDPRODUTO'], $rows["QTMESES"], $item['CDMARCA'])[0];
                        }
                        else
                        {
                           $row['QTACOMPRAR'] = $this->controlePedidoColetaService->selectQtdeAComprarMediaAF2($row, $row["CDREGIAO"], $item['CDPRODUTO'], $rows["QTMESES"], $item['CDMARCA'])[0];
                        }
                        $row['QTACOMPRAR'] = $row['QTACOMPRAR']['QTDEACOMPRAR'];
                        $row['CDPRODUTO'] = $item['CDPRODUTO'];
                        $this->controlePedidoColetaService->atualizaQtdeAComprarMediaAF($row, $row["CDREGIAO"], $row["CDFORNECED"] , $row["NRPEDCOLETA"]);
                    }
                }
            }

            $response->addMessage(new DTO\Response\Message($row));
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 1));
        }
    }
    
    public function incluirExcluirRegiao(DTO\Request $request, DTO\Response $response){
        $row = $request->getRow();
        $errorRegioes = array();
        $errorMsg = "As seguintes regiões já existiam nos respectivos pedidos:<br>";
        $success = "<br>As demais regiões foram salvas com sucesso!";
        $errorMsgDel = "As seguintes regiões não foram encontradas nos respectivos pedidos:<br>";
        $successDel = "<br>As demais regiões foram excluídas com sucesso!";
        $regioesIncluidas = array();
        $regioesExcluidas = array();
        $errorRegioesSave = false;
        $errorRegioesDelete = false;
        try{
            $this->controlePedidoColetaService->iniciaTransacao();
            foreach ($row['PEDIDOS'] as $pedido) {
                $pedido['EMAIL_LOGADO'] = $row['EMAIL_LOGADO'];
                $pedido['FILIAL_LOGADA'] = $row['FILIAL_LOGADA'];
                if($row['OPERACAO'] === 'save'){
                    $this->controlePedidoColetaService->incluirRegiao($pedido, $row['REGIAO'], $row['DTPEDCOLETA'], $errorRegioes, $regioesIncluidas);

                    if (!empty($regioesIncluidas)) {
                        $this->salvarComentarioRegiao($pedido, $row, $regioesIncluidas, $regioesExcluidas, $response);
                    } else {
                        $success = "";
                    }
                    
                    if(!empty($errorRegioes)){
                        foreach($errorRegioes as $errorRegiao){
                            $errorMsg .=  $errorRegiao['NRPEDIDOCOL'] . " - " . $errorRegiao['REGIAO'] . "<br>";
                        }
                        $errorRegioesSave = true;
                    }else{
                        $errorRegioesSave = false;
                        $msg = "Salvo com sucesso!";
                        $dataset = array(
                            "SUCCESSPEDIDOS"   => $msg
                        );
                    }
                }else{
                    $this->controlePedidoColetaService->excluirRegiao($pedido, $row['REGIAO'], $errorRegioes, $regioesExcluidas);
                    
                    if (!empty($regioesExcluidas)) {
                        $this->salvarComentarioRegiao($pedido, $row, $regioesIncluidas, $regioesExcluidas, $response);
                    } else {
                        $successDel = "";
                    }
                    
                    if(!empty($errorRegioes)){
                        foreach($errorRegioes as $errorRegiao){
                            $errorMsgDel .=  $errorRegiao['NRPEDIDOCOL'] . " - " . $errorRegiao['REGIAO'] . "<br>";
                        }
                        $errorRegioesDelete = true;
                        
                    }else{
                        $errorRegioesDelete = false;
                        $msg = "Excluído com sucesso!";
                        $dataset = array(
                            "SUCCESSPEDIDOS"   => $msg
                        );
                    }
                    
                }
            }
            if($errorRegioesSave){
                $errorMsg .= $success;
                $dataset = array(
                    "ERROPEDIDOS"   => $errorMsg
                );
            }
            if($errorRegioesDelete){
                $errorMsgDel .= $successDel;
                $dataset = array(
                    "ERROPEDIDOS"   => $errorMsgDel
                );
            }
            $response->addDataSet(new DataSet("data", $dataset));
            $this->controlePedidoColetaService->commit();
        } catch(\Exception $e){
            $this->controlePedidoColetaService->rollback();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 1));
        }
    }
    
    public function salvarComentarioRegiao($pedido, $row, $regioesIncluidas, $regioesExcluidas, $response)
    {
        try {
            $tag = "<br>";
            $count = 0;
            if($row['OPERACAO'] === 'save' && !empty($regioesIncluidas)){
                $msgRegiao = "Foram incluídas as seguintes regiões no pedido " . $pedido["NRPEDIDOCOL"] . ": <br>";
                $length = count($regioesIncluidas);
                foreach($regioesIncluidas as $regiaoIncluida){
                    if($count === ($length - 1)){
                        $tag = '';
                    }
                    $msgRegiao .= $regiaoIncluida["CDREGIAO"]  . " - " . $regiaoIncluida["NMREGIAO"] . $tag;
                    $count++;
                }
            }else if (!empty($regioesExcluidas)){
                $msgRegiao = "Foram excluídas as seguintes regiões no pedido " . $pedido["NRPEDIDOCOL"] . ": <br>";
                $length = count($regioesExcluidas);
                $count = 0;
                foreach($regioesExcluidas as $regiaoExcluida){
                    if($count === ($length - 1)){
                        $tag = '';
                    }
                    $msgRegiao .= $regiaoExcluida["CDREGIAO"]  . " - " . $regiaoExcluida["NMREGIAO"] . $tag;
                    $count++;
                }
            }
            
            $pedido['TXCOMENTARIO'] = $msgRegiao;
            $pedido['TXEMAIL'] = $msgRegiao;
            $this->controlePedidoColetaService->salvarComentario($pedido, true);
            $infoComentario  = $this->controlePedidoColetaService->infoComentario($pedido);
            $this->enviaEmailComentarioRegiao($infoComentario, $pedido, $response);
        } catch (\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 1));
        }
    }
    
    public function enviaEmailComentarioRegiao($infoComentario, $row, $response){
        try{

            $assunto = 'Comentário - '.$infoComentario["NRPEDIDOCOL"];
            $message = $this->controlePedidoColetaService->getMessageIncluirExcluirRegião($infoComentario, $row['TXEMAIL']);
            $messageSendMail = $this->supUtilities->messageSendMail($row['FILIAL_LOGADA'], $assunto, $message, 'PORTAL E-COMMERCE');
            $emailFornecedor = $this->supUtilities->retornarEmailsRelacionadosFornecedor([$row['CDFORNECED']]);
            
            $this->supUtilities->enviaEmail($row["EMAIL_LOGADO"], $assunto, $emailFornecedor, $messageSendMail, $emailFornecedor);
        }catch(\Exception $e){
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(),500));
        }
    }
    
    public function liberarInconsistencias(DTO\Request $request, DTO\Response $response)
    {
        $row = $request->getRow();
        $pedidosInconsistentes = array();
        $pedidosGeraCot = array();
        $dataset = array();

        try {
            $this->controlePedidoColetaService->iniciaTransacao();
            
            foreach ($row['PEDIDOS'] as $pedido) {
                $pedido['IDCONSISTE']  = 'S';
                $code = $this->controlePedidoColetaService->ACEITA_PEDCOTWEB($pedido);
                
                if ($code['P_IDACEITEOK'] === 'OK') {
                    $pedido['EMAIL_LOGADO'] = $row['EMAIL_LOGADO'];
                    $pedido['FILIAL_LOGADA'] = $row['FILIAL_LOGADA'];
                    $pedidoAceito = $this->controlePedidoColetaService->alteraStatus($pedido['NRPEDIDOCOL'], $pedido['CDFILIAL'], $pedido['CDFORNECED'], $pedido['NRPEDCOLETA'], 'liberarInconsistencia');
                    $this->salvarComentarioInconsistencia($pedido);
                    $infoComentario  = $this->controlePedidoColetaService->infoComentario($pedido);
                    $this->enviaEmailComentario($infoComentario, $pedido, $response, 'liberarInconsistencia');
                    if($pedidoAceito){
                        $pedidosGeraCot[] = $pedido['NRPEDIDOCOL'];
                    }
                    
                } else {
                    array_push($pedidosInconsistentes, array( "NRPEDIDOCOL" => $pedido['NRPEDIDOCOL'], "INSCRICAO" => $pedido["CDFORNECED"], "FORNECEDOR" => $pedido["FORNECEDOR"]));
                }
            }
            
            if (!empty($pedidosInconsistentes)) {
                $params = "";
                
                foreach ($pedidosInconsistentes as $pedidoInconsistente) {
                    $params .= "<tr><td class='testOnError'>" .$pedidoInconsistente['NRPEDIDOCOL'] . "</td><td class='testOnError'>" . $pedidoInconsistente['INSCRICAO'] . "</td><td class='testOnError'>" . $pedido["FORNECEDOR"] . "</td>";
                }
                $dataset['PEDIDOSINCONSISTENTES'] = true;
                $dataset['CODE'] = 'PEDIDOS_AINDA_INCONSIST';
                $dataset['PARAM'] = $params;
                
            } else {
                $dataset['SUCCESSPEDIDOS'] = true;
                $dataset['CODE'] = 'INCONSIST_LIBERADAS';
            }
            if (!empty($pedidosGeraCot)) {
                $dataset['GERACOTACAO'] = $pedidosGeraCot;
            }
            
            $response->addDataSet(new DataSet("data", $dataset));
            
            $this->controlePedidoColetaService->commit();
        } catch(\Exception $e){
            $this->controlePedidoColetaService->rollback();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 1));
        }
    }
    
    public function salvarComentarioInconsistencia($pedido){
        $msgComentario = "As inconsistências do pedido " . $pedido["NRPEDIDOCOL"] . " foram liberadas. Gentileza aceitar novamente o pedido.";
        $pedido['TXCOMENTARIO'] = $msgComentario;
        $this->controlePedidoColetaService->salvarComentario($pedido, false);
    }
    
    public function verificaInconsistencia(DTO\Request $request, DTO\Response $response) {
        try {
            $params = $request->getRow();
            $code = $this->controlePedidoColetaService->ACEITA_PEDCOTWEB($params);
            $response->addDataSet(new DataSet ('idaceiteok', array($code['P_IDACEITEOK'])));
        } catch (\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function excluirProdutos(DTO\Request $request, DTO\Response $response){
        $produtos = $request->getRow();
        $nrPedColeta = $produtos['NRPEDCOLETA'];
        $montaMensagem = 'Os seguintes produtos foram removidos do pedido ' . $produtos['PRODUTOS'][0]['NRPEDIDOCOL'] . ': ';
        try {
            $this->controlePedidoColetaService->iniciaTransacao();
            
            foreach ($produtos['PRODUTOS'] as $produto) {
                $this->controlePedidoColetaService->excluirProdutos($produto, $nrPedColeta);
                $montaMensagem .= $produto['CDARVPRODFORMAT'] . ' - ' . $produto['NMPRODUTO'] . ' da marca ' . $produto['CDMARCA'] . ' - ' . $produto['NMMARCA'] . ', ';
            }
            $msgComentario = substr($montaMensagem, 0, -2) . '.';
            $row['TXCOMENTARIO'] = $msgComentario;
            $row['CDFILIAL'] = $produtos['PRODUTOS'][0]['CDFILIAL'];
            $row['NRPEDIDOCOL'] = $produtos['PRODUTOS'][0]['NRPEDIDOCOL'];
            $this->controlePedidoColetaService->salvarComentario($row, false);
            $this->controlePedidoColetaService->flush();
            $this->controlePedidoColetaService->commit();
        } catch(\Exception $e) {
            $this->controlePedidoColetaService->rollback();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 1));
        }
    }
    
    public function getIdSisDos(DTO\Request $request, DTO\Response $response) {
        try {
            $idSisDos = $this->controlePedidoColetaService->getIdSisDos();
            $dataset = array(
                "IDSISDOS"   => $idSisDos
            );
            $response->addDataSet(new DataSet('data', $dataset));
        } catch (\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function verifyRegionsFromOrder(DTO\Request $request, DTO\Response $response) {
        try {
            $rows = $request->getRow();
            $returnArray = [];
            
            foreach ($rows as $i => $row) {
                if ($row["NRPEDIDOCOL"]) {
                    $dataset = $this->controlePedidoColetaService->verifyRegionsFromOrder($row);
                
                    $returnArray[$dataset["NRPEDIDOCOL"]] = $dataset["NUMREGIOES"]; 
                }
            }
            $dataset = $this->controlePedidoColetaService->verifyRegionsFromOrder($row);
            $response->addDataSet(new DataSet('regions', $returnArray));
        } catch (\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function insertMarcPedCol(DTO\Request $request, DTO\Response $response) 
    {
        try {
            $row = $request->getRow();
            $this->controlePedidoColetaService->insertMarcPedCol($row);
        } catch (\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function insertItemPedCol(DTO\Request\Row $request, DTO\Response $response) 
    {
        try {
            $row = $request->getRow();
            $this->controlePedidoColetaService->insertItemPedCol($row);
        } catch (\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 1));
        }
    }
    
    public function insertComentPedCol(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            $result = $this->controlePedidoColetaService->insertComentPedCol($row);
            $this->controlePedidoColetaService->enviaEmailComentario($result, $row, $response);
        } catch (\Exception $e){
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 1));
        }
	}
	
	public function alterarDataValidade(DTO\Request $request, DTO\Response $response)
	{
        try {
            $this->controlePedidoColetaService->iniciaTransacao();
            
    	    $row = $request->getRow();
    	    
    	    $cdfilial = '';
    	    $nrpedido = '';
    	    
    	    foreach ($row['PEDIDOS'] as $pedido) {
    	        $cdfilial .= $pedido['FILIAL'] . "_";
                $nrpedido .= $pedido['PEDIDO'] . "_";
    	    }
    	    
    	    $this->controlePedidoColetaService->atualizaDataValidadePedcolgeral($nrpedido, $cdfilial, $row['DTINICIAL'], $row['DTFINAL']);
    	    $this->controlePedidoColetaService->atualizaDataValidadePedcoleta($nrpedido, $row['DTINICIAL'], $row['DTFINAL']);
    	    
    	    $this->controlePedidoColetaService->commit();
        } catch(\Exception $e) {
            $this->controlePedidoColetaService->rollback();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 1));
        }
	}
	
    public function dadosErroPedCot(DTO\Request\Filter  $request, DTO\Response $response) {

		    $onDemandFilter = $request->getFilterCriteria();
            $conditions = $onDemandFilter->getConditions();
            
            $mensagens = $conditions[2];

            $onDemandFilter->setDataSourceName('logngerapedcol');
            
            $newFilterCriteria = $this->crudService->getPopulatedFilterCriteria($onDemandFilter, array());
            $dataSource = $this->dataSourceManager->findBy($newFilterCriteria);

            $dataSet = self::montaDataSet($dataSource->getRows(), $mensagens);
            $response->addDataSet(new DataSet('data', $dataSet));
	
	}
	
	public function montaDataSet(array $dataSource, $mensagens) {
        $dataSet = array();
        
        foreach($dataSource as $data){
            //tratar aqui
            $pieces = str_split($data['IDMOTNGERPEDCOL']);
        	for($i = 0; $i < count($pieces); $i++){
        	    
        	   if($pieces[$i] == '1'){
        			switch ($i) {
					  case 0:
					  	$data['IDMOTNGERPEDCOL'] = $mensagens['value'][0];
					      break;
					      
					  case 1:
						$data['IDMOTNGERPEDCOL'] = $mensagens['value'][1];
					      break;
					  case 2:
						$data['IDMOTNGERPEDCOL'] = $mensagens['value'][2];
					      break;
					      
					  case 3:
						$data['IDMOTNGERPEDCOL'] = $mensagens['value'][3];
					      break;
					      
					  case 4:
						$data['IDMOTNGERPEDCOL'] = $mensagens['value'][4];
					      break;
					      
  				      case 5:
						$data['IDMOTNGERPEDCOL'] = $mensagens['value'][5];
					      break;
  				      case 6:
						$data['IDMOTNGERPEDCOL'] = $mensagens['value'][6];
					      break;
  				      case 7:
						$data['IDMOTNGERPEDCOL'] = $mensagens['value'][7];
					      break;
  				      case 8:
						$data['IDMOTNGERPEDCOL'] = $mensagens['value'][8];
					      break;
					      
					  case 9:
						$data['IDMOTNGERPEDCOL'] = $mensagens['value'][9];
					      break;
					      
					    default:
					      break;
					  }
					  
        	   array_push($dataSet, array(
                'NMFANTFORN'     => $data['NMFANTFORN'],
                'NRINSJURFORN'    => $data['NRINSJURFORN'],
                'NMREGIAO' => $data['NMREGIAO'],
                'CDREGIAO'    => $data['CDREGIAO'],
                'NRORG'           => $data['NRORG'],
               'REGIAO'           => $data['REGIAO'],
               'FORNECEDOR'           => $data['FORNECEDOR'],
               'PEDIDO'           => $data['PEDIDO'],
               'PRODUTO'           => $data['PRODUTO'],
               'IDMOTNGERPEDCOL'           => $data['IDMOTNGERPEDCOL']
            ));
        			
        		}
        	

        	}

        }

        return $dataSet;
    }
}